==> react-native-components-8.0.5-alpha.0.tgz: package/core/Header/HeaderContent.js <==
import React, { useCallback } from 'react';
import { Animated, StyleSheet, TextInput, View, I18nManager, Platform, } from 'react-native';
import color from 'color';
import { ICON_SIZE, ICON_SPACING } from './constants';
import { useSearch } from './contexts/SearchContextProvider';
import { useColor } from './contexts/ColorContextProvider';
import { useHeaderHeight } from './contexts/HeaderHeightContextProvider';
import { useHeaderDimensions } from '../__hooks__/useHeaderDimensions';
import { useFontScale, useFontScaleSettings } from '../__contexts__/font-scale-context';
import { useFontStyles } from '../Utility/shared';
const headerContentStyles = StyleSheet.create({
    titleContainer: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'flex-end',
    },
    searchContainer: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'center',
        marginRight: 56,
        marginTop: 0,
    },
});
/**
 * HeaderTitle component
 *
 * The HeaderTitle is a helper component for organizing the contents in the Header. It is
 * used for displaying and resizing the title text.
 */
const HeaderTitle = (props) => {
    const { title, style } = props;
    const { color: textColor } = useColor();
    const { headerHeight } = useHeaderHeight();
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    const { maxScale, disableScaling } = useFontScaleSettings();
    const { fontStyleSemiBold } = useFontStyles();
    const getTitleStyle = useCallback(() => (Object.assign(Object.assign({ color: textColor }, fontStyleSemiBold), { fontSize: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [20, 30],
            extrapolate: 'clamp',
        }), writingDirection: I18nManager.isRTL ? 'rtl' : 'ltr', textAlign: Platform.OS === 'android' ? 'left' : 'auto' })), [textColor, headerHeight, REGULAR_HEIGHT, EXTENDED_HEIGHT, fontStyleSemiBold]);
    return typeof title === 'string' ? (React.createElement(Animated.Text, { testID: 'header-title', style: [getTitleStyle(), style], numberOfLines: 1, ellipsizeMode: 'tail', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }, title)) : (React.createElement(React.Fragment, null, title));
};
/**
 * HeaderSubtitle component
 *
 * The HeaderSubtitle is a helper component for organizing the contents in the Header. It is
 * used for displaying and resizing the subtitle text.
 */
const HeaderSubtitle = (props) => {
    const { subtitle, style } = props;
    const { color: textColor } = useColor();
    const { maxScale, disableScaling } = useFontScaleSettings();
    const { headerHeight } = useHeaderHeight();
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    const { fontStyleRegular } = useFontStyles();
    const getSubtitleStyle = useCallback(() => (Object.assign(Object.assign({ color: textColor }, fontStyleRegular), { fontSize: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [14, 16],
            extrapolate: 'clamp',
        }), writingDirection: I18nManager.isRTL ? 'rtl' : 'ltr', textAlign: Platform.OS === 'android' ? 'left' : 'auto' })), [textColor, headerHeight, REGULAR_HEIGHT, EXTENDED_HEIGHT, fontStyleRegular]);
    if (subtitle) {
        return typeof subtitle === 'string' ? (React.createElement(Animated.Text, { testID: 'header-subtitle', style: [getSubtitleStyle(), style], numberOfLines: 1, ellipsizeMode: 'tail', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }, subtitle)) : (React.createElement(React.Fragment, null, subtitle));
    }
    return null;
};
/**
 * HeaderInfo component
 *
 * The HeaderInfo is a helper component for organizing the contents in the Header. It is
 * used for displaying and resizing the info text.
 */
const HeaderInfo = (props) => {
    const { info, style } = props;
    const { color: textColor } = useColor();
    const { headerHeight } = useHeaderHeight();
    const { maxScale, disableScaling } = useFontScaleSettings();
    const fontScale = useFontScale();
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    const { fontStyleRegular } = useFontStyles();
    const getInfoStyle = useCallback(() => (Object.assign(Object.assign({ color: textColor, marginTop: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [-2 * fontScale, 0],
            extrapolate: 'clamp',
        }), opacity: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [0, 1],
            extrapolate: 'clamp',
        }) }, fontStyleRegular), { fontSize: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [0.1, 14],
            extrapolate: 'clamp',
        }), writingDirection: I18nManager.isRTL ? 'rtl' : 'ltr', textAlign: Platform.OS === 'android' ? 'left' : 'auto' })), [textColor, headerHeight, REGULAR_HEIGHT, EXTENDED_HEIGHT, fontScale, fontStyleRegular]);
    if (info) {
        return typeof info === 'string' ? (React.createElement(Animated.Text, { testID: 'header-info', style: [getInfoStyle(), style], numberOfLines: 1, ellipsizeMode: 'tail', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }, info)) : (React.createElement(React.Fragment, null, info));
    }
    return null;
};
/**
 * SearchContent component
 *
 * The SearchContent is a helper component for organizing the contents in the Header. It is
 * used for displaying and styling the search input. It retrieves the search configuration via
 * the useSearch hook.
 */
const SearchContent = (props) => {
    const { theme, style } = props;
    const { searchConfig = {}, onQueryChange, searchRef } = useSearch();
    const { color: textColor } = useColor();
    const { maxScale, disableScaling } = useFontScaleSettings();
    const placeholderTextColor = color(textColor).fade(0.4).string();
    return (React.createElement(TextInput, { key: 'search-input', ref: searchRef, style: [
            Object.assign({ padding: 0, color: textColor }, theme.fonts.titleMedium),
            style,
        ], autoCapitalize: searchConfig.autoCapitalize || 'none', autoCorrect: searchConfig.autoCorrect || false, autoFocus: searchConfig.autoFocus, numberOfLines: 1, onChangeText: onQueryChange, placeholder: searchConfig.placeholder || 'Search', placeholderTextColor: placeholderTextColor, returnKeyType: 'search', selectionColor: placeholderTextColor, underlineColorAndroid: 'transparent', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }));
};
/**
 * HeaderContent component
 *
 * The HeaderContent is a helper component for organizing the contents in the Header. It is
 * a wrapper that organizes the title, subtitle, info, and search inputs appropriately.
 */
export const HeaderContent = (props) => {
    const { title, subtitle, info, actions = { components: { count: 0, width: 0 }, icons: { count: 0 } }, theme, styles = {}, } = props;
    const { headerHeight } = useHeaderHeight();
    const { searching, searchConfig } = useSearch();
    const fontScale = useFontScale();
    const defaultStyles = headerContentStyles;
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    let content = [];
    if (searchConfig && searching) {
        content = [React.createElement(SearchContent, { key: 'search-content', theme: theme, style: styles.search })];
    }
    else {
        content = [
            React.createElement(HeaderTitle, { title: title, key: "title_key", theme: theme, style: [styles.title] }),
            React.createElement(HeaderSubtitle, { subtitle: subtitle, key: "subtitle_key", theme: theme, style: [styles.subtitle] }),
            React.createElement(HeaderInfo, { info: info, key: "info_key", theme: theme, style: [styles.info] }),
        ];
    }
    const getActionPanelWidth = useCallback(() => {
        let iconLength = actions.icons.count;
        const componentsLength = actions.components.count;
        const componentsWidth = actions.components.width;
        if (searchConfig)
            iconLength++;
        if (iconLength + componentsLength < 1)
            return 0;
        return iconLength * (ICON_SIZE * fontScale + ICON_SPACING) + componentsWidth;
    }, [actions, searchConfig, fontScale]);
    return (React.createElement(Animated.View, { style: [
            searching ? defaultStyles.searchContainer : defaultStyles.titleContainer,
            searching
                ? {}
                : {
                    marginRight: headerHeight.interpolate({
                        inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
                        outputRange: [getActionPanelWidth(), 0],
                        extrapolate: 'clamp',
                    }),
                    marginBottom: subtitle && title ? 5 * fontScale : 15 * fontScale,
                },
            styles.root,
        ] },
        React.createElement(View, { style: { flex: 0, flexBasis: 'auto', justifyContent: 'center' } }, content)));
};

==> react-native-components-9.0.0-alpha.0.tgz: package/core/Header/HeaderContent.js <==
import React, { useCallback } from 'react';
import { Animated, StyleSheet, TextInput, View, I18nManager, Platform, } from 'react-native';
import color from 'color';
import { ICON_SIZE, ICON_SPACING } from './constants.js';
import { useSearch } from './contexts/SearchContextProvider.js';
import { useColor } from './contexts/ColorContextProvider.js';
import { useHeaderHeight } from './contexts/HeaderHeightContextProvider.js';
import { useHeaderDimensions } from '../__hooks__/useHeaderDimensions.js';
import { useFontScale, useFontScaleSettings } from '../__contexts__/font-scale-context.js';
import { useFontStyles } from '../Utility/shared.js';
const headerContentStyles = StyleSheet.create({
    titleContainer: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'flex-end',
    },
    searchContainer: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'center',
        marginRight: 56,
        marginTop: 0,
    },
});
/**
 * HeaderTitle component
 *
 * The HeaderTitle is a helper component for organizing the contents in the Header. It is
 * used for displaying and resizing the title text.
 */
const HeaderTitle = (props) => {
    const { title, style } = props;
    const { color: textColor } = useColor();
    const { headerHeight } = useHeaderHeight();
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    const { maxScale, disableScaling } = useFontScaleSettings();
    const { fontStyleSemiBold } = useFontStyles();
    const getTitleStyle = useCallback(() => ({
        color: textColor,
        ...fontStyleSemiBold,
        fontSize: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [20, 30],
            extrapolate: 'clamp',
        }),
        writingDirection: I18nManager.isRTL ? 'rtl' : 'ltr',
        textAlign: Platform.OS === 'android' ? 'left' : 'auto',
    }), [textColor, headerHeight, REGULAR_HEIGHT, EXTENDED_HEIGHT, fontStyleSemiBold]);
    return typeof title === 'string' ? (React.createElement(Animated.Text, { testID: 'header-title', style: [getTitleStyle(), style], numberOfLines: 1, ellipsizeMode: 'tail', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }, title)) : (React.createElement(React.Fragment, null, title));
};
/**
 * HeaderSubtitle component
 *
 * The HeaderSubtitle is a helper component for organizing the contents in the Header. It is
 * used for displaying and resizing the subtitle text.
 */
const HeaderSubtitle = (props) => {
    const { subtitle, style } = props;
    const { color: textColor } = useColor();
    const { maxScale, disableScaling } = useFontScaleSettings();
    const { headerHeight } = useHeaderHeight();
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    const { fontStyleRegular } = useFontStyles();
    const getSubtitleStyle = useCallback(() => ({
        color: textColor,
        ...fontStyleRegular,
        fontSize: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [14, 16],
            extrapolate: 'clamp',
        }),
        writingDirection: I18nManager.isRTL ? 'rtl' : 'ltr',
        textAlign: Platform.OS === 'android' ? 'left' : 'auto',
    }), [textColor, headerHeight, REGULAR_HEIGHT, EXTENDED_HEIGHT, fontStyleRegular]);
    if (subtitle) {
        return typeof subtitle === 'string' ? (React.createElement(Animated.Text, { testID: 'header-subtitle', style: [getSubtitleStyle(), style], numberOfLines: 1, ellipsizeMode: 'tail', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }, subtitle)) : (React.createElement(React.Fragment, null, subtitle));
    }
    return null;
};
/**
 * HeaderInfo component
 *
 * The HeaderInfo is a helper component for organizing the contents in the Header. It is
 * used for displaying and resizing the info text.
 */
const HeaderInfo = (props) => {
    const { info, style } = props;
    const { color: textColor } = useColor();
    const { headerHeight } = useHeaderHeight();
    const { maxScale, disableScaling } = useFontScaleSettings();
    const fontScale = useFontScale();
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    const { fontStyleRegular } = useFontStyles();
    const getInfoStyle = useCallback(() => ({
        color: textColor,
        marginTop: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [-2 * fontScale, 0],
            extrapolate: 'clamp',
        }),
        opacity: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [0, 1],
            extrapolate: 'clamp',
        }),
        ...fontStyleRegular,
        fontSize: headerHeight.interpolate({
            inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
            outputRange: [0.1, 14],
            extrapolate: 'clamp',
        }),
        writingDirection: I18nManager.isRTL ? 'rtl' : 'ltr',
        textAlign: Platform.OS === 'android' ? 'left' : 'auto',
    }), [textColor, headerHeight, REGULAR_HEIGHT, EXTENDED_HEIGHT, fontScale, fontStyleRegular]);
    if (info) {
        return typeof info === 'string' ? (React.createElement(Animated.Text, { testID: 'header-info', style: [getInfoStyle(), style], numberOfLines: 1, ellipsizeMode: 'tail', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }, info)) : (React.createElement(React.Fragment, null, info));
    }
    return null;
};
/**
 * SearchContent component
 *
 * The SearchContent is a helper component for organizing the contents in the Header. It is
 * used for displaying and styling the search input. It retrieves the search configuration via
 * the useSearch hook.
 */
const SearchContent = (props) => {
    const { theme, style } = props;
    const { searchConfig = {}, onQueryChange, searchRef } = useSearch();
    const { color: textColor } = useColor();
    const { maxScale, disableScaling } = useFontScaleSettings();
    const placeholderTextColor = color(textColor).fade(0.4).string();
    return (React.createElement(TextInput, { key: 'search-input', ref: searchRef, style: [
            {
                padding: 0,
                color: textColor,
                ...theme.fonts.titleMedium,
            },
            style,
        ], autoCapitalize: searchConfig.autoCapitalize || 'none', autoCorrect: searchConfig.autoCorrect || false, autoFocus: searchConfig.autoFocus, numberOfLines: 1, onChangeText: onQueryChange, placeholder: searchConfig.placeholder || 'Search', placeholderTextColor: placeholderTextColor, returnKeyType: 'search', selectionColor: placeholderTextColor, underlineColorAndroid: 'transparent', allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }));
};
/**
 * HeaderContent component
 *
 * The HeaderContent is a helper component for organizing the contents in the Header. It is
 * a wrapper that organizes the title, subtitle, info, and search inputs appropriately.
 */
export const HeaderContent = (props) => {
    const { title, subtitle, info, actions = { components: { count: 0, width: 0 }, icons: { count: 0 } }, theme, styles = {}, } = props;
    const { headerHeight } = useHeaderHeight();
    const { searching, searchConfig } = useSearch();
    const fontScale = useFontScale();
    const defaultStyles = headerContentStyles;
    const { REGULAR_HEIGHT, EXTENDED_HEIGHT } = useHeaderDimensions();
    let content = [];
    if (searchConfig && searching) {
        content = [React.createElement(SearchContent, { key: 'search-content', theme: theme, style: styles.search })];
    }
    else {
        content = [
            React.createElement(HeaderTitle, { title: title, key: "title_key", theme: theme, style: [styles.title] }),
            React.createElement(HeaderSubtitle, { subtitle: subtitle, key: "subtitle_key", theme: theme, style: [styles.subtitle] }),
            React.createElement(HeaderInfo, { info: info, key: "info_key", theme: theme, style: [styles.info] }),
        ];
    }
    const getActionPanelWidth = useCallback(() => {
        let iconLength = actions.icons.count;
        const componentsLength = actions.components.count;
        const componentsWidth = actions.components.width;
        if (searchConfig)
            iconLength++;
        if (iconLength + componentsLength < 1)
            return 0;
        return iconLength * (ICON_SIZE * fontScale + ICON_SPACING) + componentsWidth;
    }, [actions, searchConfig, fontScale]);
    return (React.createElement(Animated.View, { style: [
            searching ? defaultStyles.searchContainer : defaultStyles.titleContainer,
            searching
                ? {}
                : {
                    marginRight: headerHeight.interpolate({
                        inputRange: [REGULAR_HEIGHT, EXTENDED_HEIGHT],
                        outputRange: [getActionPanelWidth(), 0],
                        extrapolate: 'clamp',
                    }),
                    marginBottom: subtitle && title ? 5 * fontScale : 15 * fontScale,
                },
            styles.root,
        ] },
        React.createElement(View, { style: { flex: 0, flexBasis: 'auto', justifyContent: 'center' } }, content)));
};
